"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSocketContext = exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _Context = require("./Context");
var _socket = require("socket.io-client");
var _ChatConfigurations = require("../ChatConfigurations");
var _Message = require("../../types/Message");
var _getHourAndMinutes = require("../../utils/getHourAndMinutes");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const SocketComponent = props => {
  const channel = 'webchat';
  const socketUrl = 'https://7cb9-2804-431-cff7-5484-b43c-67d6-c3e4-2363.ngrok.io';
  const {
    children,
    botId
  } = props;
  const {
    setBotConfigs
  } = (0, _ChatConfigurations.useChatConfigurations)();
  const clientRef = (0, _react.useRef)(null);
  const [messages, setMessages] = (0, _react.useState)([]);
  const [sessionId, setSessionId] = (0, _react.useState)(null);
  const addMessage = (0, _react.useCallback)(message => {
    setMessages(prevState => [...(prevState.filter(m => m.type !== _Message.MessageTypes.TYPING) ?? []), {
      ...message,
      hour: (0, _getHourAndMinutes.getHourAndMinutes)()
    }]);
  }, []);
  const handleSubmitMessage = (0, _react.useCallback)(_ref => {
    var _clientRef$current;
    let {
      message,
      type,
      ext
    } = _ref;
    const isMedia = type !== _Message.MessageTypes.TEXT;
    clientRef === null || clientRef === void 0 ? void 0 : (_clientRef$current = clientRef.current) === null || _clientRef$current === void 0 ? void 0 : _clientRef$current.emit('message', {
      botId: botId,
      message,
      isMedia,
      ext,
      id: sessionId,
      botChannel: 'WebChat'
    });
    setMessages(prevState => [...prevState, {
      from: _Message.From.USER,
      message,
      type,
      hour: (0, _getHourAndMinutes.getHourAndMinutes)()
    }]);
  }, [sessionId]);
  const handleStartConversation = (0, _react.useCallback)(_sessionId => {
    var _clientRef$current2;
    setSessionId(_sessionId);
    clientRef === null || clientRef === void 0 ? void 0 : (_clientRef$current2 = clientRef.current) === null || _clientRef$current2 === void 0 ? void 0 : _clientRef$current2.emit('start', {
      botId: botId,
      id: _sessionId,
      channel: channel,
      botChannel: 'WebChat',
      contactNumber: sessionId
    });
  }, [clientRef]);
  const startNewSession = client => {
    client.emit('subscribe', {
      botId: botId,
      botChannel: 'WebChat'
    });
  };
  const handleOpenLink = (0, _react.useCallback)(async url => {
    await _reactNative.Linking.openURL(url);
  }, []);
  const handleCarouselButtonClick = _ref2 => {
    var _clientRef$current3;
    let {
      clickedButton,
      clickedCard
    } = _ref2;
    const {
      destination
    } = clickedButton;
    if ((destination === null || destination === void 0 ? void 0 : destination.type) === _Message.CarouselDestinationTypes.URL) {
      handleOpenLink(destination === null || destination === void 0 ? void 0 : destination.value);
    }
    if ((destination === null || destination === void 0 ? void 0 : destination.type) === _Message.CarouselDestinationTypes.PHONE) {
      var _destination$value;
      const treated = destination === null || destination === void 0 ? void 0 : (_destination$value = destination.value) === null || _destination$value === void 0 ? void 0 : _destination$value.replace(/[^A-Z0-9]/gi, '');
      handleOpenLink(`tel:+55${treated}`);
    }
    clientRef === null || clientRef === void 0 ? void 0 : (_clientRef$current3 = clientRef.current) === null || _clientRef$current3 === void 0 ? void 0 : _clientRef$current3.emit('action', {
      botId: botId,
      action: {
        type: _Message.MessageTypes.CAROUSEL,
        data: {
          clickedButton,
          clickedCard
        }
      },
      id: sessionId
    });
  };
  (0, _react.useEffect)(() => {
    if (!clientRef.current) {
      const client = (0, _socket.io)(socketUrl);
      clientRef.current = client;
      client.on('connect', () => {
        if (!sessionId) {
          startNewSession(client);
        }
      });
      client.on('message', data => {
        addMessage({
          ...data,
          from: _Message.From.BOT
        });
      });
      client.on('subscribe-response', data => {
        var _data$bot, _data$bot$channels, _data$bot2, _webchatChannel$setti, _webchatChannel$setti2, _webchatChannel$setti3, _webchatChannel$setti4, _webchatChannel$setti5;
        setSessionId(data === null || data === void 0 ? void 0 : data.id);
        handleStartConversation(data.id);
        const [webchatChannel] = data === null || data === void 0 ? void 0 : (_data$bot = data.bot) === null || _data$bot === void 0 ? void 0 : (_data$bot$channels = _data$bot.channels) === null || _data$bot$channels === void 0 ? void 0 : _data$bot$channels.filter(ch => {
          return ch.channelId === 'WebChat';
        });
        const botConfigs = {
          title: data === null || data === void 0 ? void 0 : (_data$bot2 = data.bot) === null || _data$bot2 === void 0 ? void 0 : _data$bot2.title,
          botFab: webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti = webchatChannel.settings) === null || _webchatChannel$setti === void 0 ? void 0 : _webchatChannel$setti.botFab,
          colors: {
            main: webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti2 = webchatChannel.settings) === null || _webchatChannel$setti2 === void 0 ? void 0 : _webchatChannel$setti2.mainColor,
            secondary: webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti3 = webchatChannel.settings) === null || _webchatChannel$setti3 === void 0 ? void 0 : _webchatChannel$setti3.secondaryColor,
            mainText: webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti4 = webchatChannel.settings) === null || _webchatChannel$setti4 === void 0 ? void 0 : _webchatChannel$setti4.mainTextColor,
            secondaryText: webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti5 = webchatChannel.settings) === null || _webchatChannel$setti5 === void 0 ? void 0 : _webchatChannel$setti5.secondaryTextColor
          }
        };
        setBotConfigs(botConfigs);
      });
      client.on('reconnect_attempt', () => {
        client.io.opts.transports = ['polling', 'websocket'];
      });
      client.on('disconnect', () => {
        if (clientRef.current) {
          console.log('ws closed by server');
        } else {
          console.log('ws closed by app component unmount');
          return;
        }
      });
      client.on('end_conversation', data => {
        if (!(data !== null && data !== void 0 && data.isTransfer)) {
          setSessionId('');
        }
      });
      return () => {
        clientRef.current = null;
        client.close();
      };
    }
    return () => {
      clientRef.current = null;
    };
  }, [botId, handleStartConversation]);
  const state = (0, _react.useMemo)(() => ({
    handleSubmitMessage,
    messages,
    handleCarouselButtonClick
  }), [messages]);
  return /*#__PURE__*/_react.default.createElement(_Context.SocketContextProvider, {
    value: state
  }, children);
};
const useSocketContext = () => {
  return (0, _react.useContext)(_Context.SocketContext);
};
exports.useSocketContext = useSocketContext;
var _default = /*#__PURE__*/(0, _react.memo)(SocketComponent);
exports.default = _default;
//# sourceMappingURL=Component.js.map