import React, { useState, useCallback } from 'react';
import { TextInput, View, Image, TouchableOpacity } from 'react-native';
import * as ImagePicker from 'expo-image-picker';
import { MessageTypes, From } from '../../../../types/Message';
import { useSocketContext } from '../../../../context/Socket/Component';
import attachIcon from '../../../../assets/attach_icon.png';
import SendIcon from '../../../../assets/icons/SendIcon';
import { styles } from './styles';
function Input() {
  const {
    handleSubmitMessage
  } = useSocketContext();
  const [userText, setUserText] = useState('');
  const onAttach = useCallback(async () => {
    var _result$assets$;
    const result = await ImagePicker.launchImageLibraryAsync({
      mediaTypes: ImagePicker.MediaTypeOptions.All,
      allowsEditing: true,
      quality: 1,
      base64: true
    });
    const uri = result.assets ? (_result$assets$ = result.assets[0]) === null || _result$assets$ === void 0 ? void 0 : _result$assets$.uri : '';
    const msg = {
      from: From.USER,
      ext: 'jpg',
      isMedia: true,
      type: MessageTypes.IMAGE,
      message: uri
    };
    handleSubmitMessage(msg);
  }, []);
  const onSend = () => {
    if (!userText) return;else {
      const msg = {
        type: MessageTypes.TEXT,
        message: userText,
        from: From.USER
      };
      handleSubmitMessage(msg);
      setUserText('');
    }
  };
  return /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(TextInput, {
    placeholder: "Digite algo ...",
    placeholderTextColor: "#979AA5",
    onChangeText: setUserText,
    style: styles.input,
    value: userText
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.icons
  }, /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: onAttach
  }, /*#__PURE__*/React.createElement(Image, {
    source: attachIcon,
    style: styles.attachIcon
  })), /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: onSend
  }, /*#__PURE__*/React.createElement(SendIcon, null))));
}
export default Input;
//# sourceMappingURL=index.js.map